Learn R Programming

Epi (version 2.47.1)

AaJ.Lexis: The Aalen-Johansen estimator of state probabilities from a multistate Lexis object.

Description

The Aalen-Johansen estimator is computed on the basis of a Lexis multistate object along a given time scale. The function is merely a wrapper for the survfit.

Usage

# S3 method for Lexis
AaJ(Lx,
               formula = ~ 1,
             timeScale = 1, ...)

Value

An object of class survfitms --- see

survfit.

Arguments

Lx

A Lexis object. The starting state must be the first among levels(Lx).

formula

A one-sided formula passed on to survfit.

timeScale

Chararter or integer, selecting one of the timescales of the Lexis object.

...

arguments passed to or from other methods.

Author

Bendix Carstensen, http://bendixcarstensen.com

See Also

survfit ci.Crisk

Examples

Run this code
data(DMlate)
str(DMlate)
dml <- Lexis(entry = list(Per = dodm,
                          Age = dodm-dobth,
                        DMdur = 0 ),
              exit = list(Per = dox),
       exit.status = factor(!is.na(dodth),
                            labels = c("DM","Dead")),
              data = DMlate )

# Cut the follow-up at insulin start
dmi <- cutLexis(dml,
                cut = dml$doins,
          new.state = "Ins",
        split.state = TRUE)
summary( dmi )
ms <- AaJ.Lexis(dmi, timeScale = "DMdur")
class(ms)
ms$states
head(ms$pstate)

Run the code above in your browser using DataLab