| LexisScarf | R Documentation |
The function generates a dotted pattern that refers to stitches of a knitting pattern. Since there are several colors involved the back side of the knit becomes quite messy, hence the pattern is for a tube-shaped scarf, that will have all the messiness on the inside. So use a circular needle for the work. And send the author a picture of your finished scarf.
LexisScarf(nw = 4, # fields around (width of scarf)
nl = 20, # fields along (length)
nm = 23, # no. stitches per field
np = 30, # no. persons
scale = 1.5, # maximal FU in units of nw
clr = c("red", "blue", "limegreen"))
nw |
number of fields around the tube |
nl |
number of fields along the tube |
nm |
no. stitches per field |
np |
no. lifelines (persons) |
scale |
maximal length of life lines in units of |
clr |
vector of colors to be used for life lines |
The function produces a graph; ask for a plotting area with
aspect ratio of nl to nw.
NULL. The function is used for its side-effect of producing a graph of the knitting pattern.
Bendix Carstensen, http://bendixcarstensen.com, b@bxc.dk
# pdf("scarf.pdf", height = 10, width = 50)
LexisScarf()
# dev.off()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.