clogistic(formula, strata, data, subset, na.action, init,
model = TRUE, x = FALSE, y = TRUE, contrasts = NULL,
iter.max=20, eps=1e-6, toler.chol = sqrt(.Machine$double.eps))contrasts.arg of
model.matrix.defaulteps.
Must be positive.eps."clogistic". This is a list containing
the following components:informative below.model=TRUE, a logical vector of length equal to the number
of rows in the model frame. This indicates whether an observation
is informative. Strata that are homogeneous with respect to either
the outcome variable or the predictor variables are uninformative,
in the sense that they can be removed without modifying the
estimates or standard errors. If model=FALSE, this is NULL.glm object: terms, formula,
call, contrasts, xlevels, and, optionally,
x, y, and/or frame.glmdata(bdendo)
clogistic(d ~ cest + dur, strata=set, data=bdendo)Run the code above in your browser using DataLab