Learn R Programming

Epi (version 2.63)

Icens: Fits a regression model to interval censored data.

Description

The models fitted assumes a piecewise constant baseline rate in intervals specified by the argument breaks, and for the covariates either a multiplicative relative risk function (default) or an additive excess risk function.

Usage

Icens(first.well, last.well, first.ill,
        formula, model.type = c("MRR", "AER"), breaks,
        boot = FALSE, alpha = 0.05, keep.sample = FALSE,
        data)
# S3 method for Icens
summary(object, scale = 1, ...)
# S3 method for Icens
print(x, scale = 1, digits = 4, ...)

Value

An object of class "Icens": a list with two or three components:

rates

A glm object from a binomial model with log-link, estimating the baseline rates, and the excess rates if "AER" is specified. The parameters in the linear predictor are rates, not log-rates. They are in units corresponding to (the inverse of) the units in which the arguments first.well, last.well, first.ill and breaks are given.

cov

A glm object from a binomial model with complementary log-log link, estimating the log-rate-ratios. Only if "MRR" is specified.

niter

Number of iterations, a scalar

boot.ci

If boot=TRUE, a 3-column matrix with estimates and 1-alpha confidence intervals for the parameters in the model.

sample

A matrix of the parameter estimates from the bootstrapping. Rows refer to parameters, columns to bootstrap samples.

Arguments

first.well

Time of entry to the study, i.e. the time first seen without event. Numerical vector.

last.well

Time last seen without event. Numerical vector.

first.ill

Time first seen with event. Numerical vector.

formula

Model formula for the log rate ratios / excess rates.

model.type

Which model should be fitted.

breaks

Breakpoints between intervals in which the underlying timescale effect is assumed constant. Any observation outside the range of breaks is discarded.

boot

Should bootstrap be performed to produce confidence intervals for parameters. If a number is given this will be the number of bootstrap samples. The default is 1000.

alpha

1 minus the confidence level.

keep.sample

Should the bootstrap sample of the parameter values be returned?

data

Data frame in which the times and formula are interpreted.

object

an Icens object.

x

an Icens object.

scale

scaling factor for rates.

digits

how many digits is used for printing results.

...

Other parameters passed on.

Author

Martyn Plummer, martyn.plummer@r-project.org, Bendix Carstensen, b@bxc.dk

Details

The model is fitted by calling either fit.mult or fit.add.

References

B Carstensen: Regression models for interval censored survival data: application to HIV infection in Danish homosexual men. Statistics in Medicine, 15(20):2177-2189, 1996.

CP Farrington: Interval censored survival data: a generalized linear modelling approach. Statistics in Medicine, 15(3):283-292, 1996.

See Also

fit.add fit.mult

Examples

Run this code
data(hivDK)
# Convert the dates to fractional years so that rates are
# expressed in cases per year and not per day
for(i in 2:4) hivDK[,i] <- cal.yr(hivDK[,i])

# multiplicative rate ratio model, baseline rates and RRs
m.RR <- Icens(entry, well, ill,
              model = "MRR",
            formula = ~ pyr + us,
             breaks = seq(1980, 1990, 5),
               data = hivDK)
# the MRR model returns a list with 2 glm objects.
round(ci.lin(m.RR$rates), 4)         # rates per 1 year
round(ci.lin(m.RR$cov, Exp=TRUE), 4) # RRs
# There is a print method that does the job:
print(m.RR)
# and scales only the rate parameters, here per 10 years
print(m.RR, scale = 10)

# additive excess rate model, baseline rates and excess rates
m.ER <- Icens(entry, well, ill,
              model = "AER",
            formula = ~ pyr + us,
             breaks = seq(1980, 1990, 5),
               data = hivDK)
# The print method returns rates per 1 year:
print(m.ER)
# or per 10 years:
print(m.ER, scale = 10)
  

Run the code above in your browser using DataLab