Learn R Programming

Epi (version 2.63)

LexisScarf: Generate a knitting pattern for a tube-shaped scarf with Lexis lines

Description

The function generates a dotted pattern that refers to stitches of a knitting pattern. Since there are several colors involved the back side of the knit becomes quite messy, hence the pattern is for a tube-shaped scarf, that will have all the messiness on the inside. So use a circular needle for the work. And send the author a picture of your finished scarf.

Usage

LexisScarf(nw = 4,   # fields around (width of scarf)           
           nl = 20,  # fields along  (length)           
           nm = 23,  # no. stitches per field   
           np = 30,  # no. persons              
        scale = 1.5, # maximal FU in units of nw
          clr = c("red", "blue", "limegreen"))

Value

NULL. The function is used for its side-effect of producing a graph of the knitting pattern.

Arguments

nw

number of fields around the tube

nl

number of fields along the tube

nm

no. stitches per field

np

no. lifelines (persons)

scale

maximal length of life lines in units of nw

clr

vector of colors to be used for life lines

Author

Bendix Carstensen, http://bendixcarstensen.com, b@bxc.dk

Details

The function produces a graph; ask for a plotting area with aspect ratio of nl to nw.

Examples

Run this code
# pdf("scarf.pdf", height = 10, width = 50)
LexisScarf()
# dev.off()

Run the code above in your browser using DataLab