LexisScarf: Generate a knitting pattern for a tube-shaped scarf with Lexis lines
Description
The function generates a dotted pattern that refers to stitches of a
knitting pattern. Since there are several colors involved the back side
of the knit becomes quite messy, hence the pattern is for a tube-shaped
scarf, that will have all the messiness on the inside. So use a circular
needle for the work. And send the author a picture of your finished scarf.
Usage
LexisScarf(nw = 4, # fields around (width of scarf)
nl = 20, # fields along (length)
nm = 23, # no. stitches per field
np = 30, # no. persons
scale = 1.5, # maximal FU in units of nw
clr = c("red", "blue", "limegreen"))
Value
NULL. The function is used for its side-effect of
producing a graph of the knitting pattern.